package check_test

import (
	"fmt"
	"reflect"
	"testing"
)

//Check return a checker
func Check(t *testing.T) Checker {
	return Checker{T: t}
}

// Checker test checking helper
type Checker struct {
	*testing.T
}

//Err check for error
func (t Checker) Err(err error) {
	msg := fmt.Sprintf("Checking for error: %v", err)
	if err != nil {
		t.Fatalf("\033[31m[FAIL] %s\033[0m", msg)
	}
	t.Logf("\033[32m[PASS]\033[m %s", msg)
}

//Eq check if equal
func (t Checker) Eq(a, b interface{}) {
	msg := fmt.Sprintf("Expect %v got %v", a, b)
	if !reflect.DeepEqual(a, b) {
		t.Fatalf("\033[31m[FAIL] %s\033[0m", msg)
	}
	t.Logf("\033[32m[PASS]\033[m %s", msg)
}

//Diff check if different
func (t Checker) Diff(a, b interface{}) {
	msg := fmt.Sprintf("Expect NOT %v got %v", a, b)
	if reflect.DeepEqual(a, b) {
		t.Fatalf("\033[31m[FAIL] %s\033[0m", msg)
	}
	t.Logf("\033[32m[PASS]\033[m %s", msg)
}
